@@ -3,6 +3,7 @@
 See https://github.com/niccokunzmann/python-recurring-ical-events/issues/117
 """
 
+
 def test_event_is_deleted(calendars):
     """No event takes place."""
-    assert not calendars.issue_117_until_before_dtstart.all()
+    assert not list(calendars.issue_117_until_before_dtstart.all())
